# MapZ

<h2>Extension of standard `dict` capabilities.</h2>

<p>
    <a href="https://github.com/ilexconf/mapz/actions"><img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/ilexconf/mapz/release?logo=github"></a>
    <a href="https://codecov.io/gh/ilexconf/mapz/"><img alt="Codecov" src="https://img.shields.io/codecov/c/github/ilexconf/mapz?logo=codecov"></a>
    <a href="https://pypi.org/project/mapz/"><img alt="PyPI" src="https://img.shields.io/pypi/v/mapz?color=blue&logo=pypi"></a>
</p>
